EXPORTS
	?CancelCreateTrafficStream@RWLMServer@@QAEXXZ @ 1 NONAME ; void RWLMServer::CancelCreateTrafficStream(void)
	?GetScanResults@RWLMServer@@QAEXAAVScanList@@ABVTDesC8@@AAHAAIAAVTRequestStatus@@@Z @ 2 NONAME ; void RWLMServer::GetScanResults(class ScanList &, class TDesC8 const &, int &, unsigned int &, class TRequestStatus &)
	?RunProtectedSetup@RWLMServer@@QAEXAAVTRequestStatus@@KAAVTDes8@@@Z @ 3 NONAME ; void RWLMServer::RunProtectedSetup(class TRequestStatus &, unsigned long, class TDes8 &)
	?RemoveIapSsidList@RWLMServer@@QAEHI@Z @ 4 NONAME ; int RWLMServer::RemoveIapSsidList(unsigned int)
	?ClearPacketStatistics@RWLMServer@@QAEXXZ @ 5 NONAME ; void RWLMServer::ClearPacketStatistics(void)
	?AddIapSsidList@RWLMServer@@QAEHIABV?$CArrayFixFlat@V?$TBuf8@$0CA@@@@@@Z @ 6 NONAME ; int RWLMServer::AddIapSsidList(unsigned int, class CArrayFixFlat<class TBuf8<32> > const &)
	?GetRegulatoryDomain@RWLMServer@@QAEHAAW4TWlanRegion@@@Z @ 7 NONAME ; int RWLMServer::GetRegulatoryDomain(enum TWlanRegion &)
	?GetBSSID@RWLMServer@@QAEHAAUTMacAddress@@@Z @ 8 NONAME ; int RWLMServer::GetBSSID(struct TMacAddress &)
	?CreateTrafficStream@RWLMServer@@QAEXAAVTRequestStatus@@ABVTWlanTrafficStreamParameters@@HAAIAAW4TWlanTrafficStreamStatus@@@Z @ 9 NONAME ; void RWLMServer::CreateTrafficStream(class TRequestStatus &, class TWlanTrafficStreamParameters const &, int, unsigned int &, enum TWlanTrafficStreamStatus &)
	?Close@RWLMServer@@QAEXXZ @ 10 NONAME ; void RWLMServer::Close(void)
	?GetPowerSaveMode@RWLMServer@@QAEHAAW4TWlanPowerSave@@@Z @ 11 NONAME ; int RWLMServer::GetPowerSaveMode(enum TWlanPowerSave &)
	?GetUapsdSettings@RWLMServer@@QAEHAAUTWlanUapsdSettings@@@Z @ 12 NONAME ; int RWLMServer::GetUapsdSettings(struct TWlanUapsdSettings &)
	?GetNetworkName@RWLMServer@@QAEHAAVTDes16@@@Z @ 13 NONAME ; int RWLMServer::GetNetworkName(class TDes16 &)
	?Release@RWLMServer@@QAEHXZ @ 14 NONAME ; int RWLMServer::Release(void)
	?CancelProtectedSetup@RWLMServer@@QAEXXZ @ 15 NONAME ; void RWLMServer::CancelProtectedSetup(void)
	?GetAccessPointInfo@RWLMServer@@QAEHAAUTWlanAccessPointInfo@@@Z @ 16 NONAME ; int RWLMServer::GetAccessPointInfo(struct TWlanAccessPointInfo &)
	?GetConnectionRCPI@RWLMServer@@QAEHAAJ@Z @ 17 NONAME ; int RWLMServer::GetConnectionRCPI(long &)
	?GetSecurityMode@RWLMServer@@QAEHAAW4TWlanSecurity@@@Z @ 18 NONAME ; int RWLMServer::GetSecurityMode(enum TWlanSecurity &)
	?DirectedRoam@RWLMServer@@QAEXAAVTRequestStatus@@ABUTMacAddress@@@Z @ 19 NONAME ; void RWLMServer::DirectedRoam(class TRequestStatus &, struct TMacAddress const &)
	?ActivateNotifiesL@RWLMServer@@QAEXAAVMWLMNotify@@K@Z @ 20 NONAME ; void RWLMServer::ActivateNotifiesL(class MWLMNotify &, unsigned long)
	?ConfigureMulticast@RWLMServer@@QAEHIABUTMacAddress@@@Z @ 21 NONAME ; int RWLMServer::ConfigureMulticast(unsigned int, struct TMacAddress const &)
	?GetPacketStatistics@RWLMServer@@QAEHAAUTWlanPacketStatistics@@@Z @ 22 NONAME ; int RWLMServer::GetPacketStatistics(struct TWlanPacketStatistics &)
	?SetUapsdSettings@RWLMServer@@QAEHABUTWlanUapsdSettings@@@Z @ 23 NONAME ; int RWLMServer::SetUapsdSettings(struct TWlanUapsdSettings const &)
	?AddBssidToRoguelist@RWLMServer@@QAEHABUTMacAddress@@@Z @ 24 NONAME ; int RWLMServer::AddBssidToRoguelist(struct TMacAddress const &)
	?GetRoamMetrics@RWLMServer@@QAEHAAUTWlanRoamMetrics@@@Z @ 25 NONAME ; int RWLMServer::GetRoamMetrics(struct TWlanRoamMetrics &)
	?CancelGetScanResults@RWLMServer@@QAEXXZ @ 26 NONAME ; void RWLMServer::CancelGetScanResults(void)
	?NotifyChangedPsmSrvMode@RWLMServer@@QAEHH@Z @ 27 NONAME ; int RWLMServer::NotifyChangedPsmSrvMode(int)
	?CancelGetAvailableIaps@RWLMServer@@QAEXXZ @ 28 NONAME ; void RWLMServer::CancelGetAvailableIaps(void)
	?GetRogueList@RWLMServer@@QAEHAAV?$CArrayFixSeg@V?$TBuf8@$05@@@@@Z @ 29 NONAME ; int RWLMServer::GetRogueList(class CArrayFixSeg<class TBuf8<6> > &)
	?CancelDirectedRoam@RWLMServer@@QAEXXZ @ 30 NONAME ; void RWLMServer::CancelDirectedRoam(void)
	?GetAcTrafficStatus@RWLMServer@@QAEHAAV?$TFixedArray@W4TWlmAcTrafficStatus@@$03@@@Z @ 31 NONAME ; int RWLMServer::GetAcTrafficStatus(class TFixedArray<enum TWlmAcTrafficStatus, 4> &)
	?GetScanResults@RWLMServer@@QAEHAAVScanList@@ABVTDesC8@@AAHAAI@Z @ 32 NONAME ; int RWLMServer::GetScanResults(class ScanList &, class TDesC8 const &, int &, unsigned int &)
	?GetAvailableIaps@RWLMServer@@QAEXAAVTDes8@@00AAVTRequestStatus@@@Z @ 33 NONAME ; void RWLMServer::GetAvailableIaps(class TDes8 &, class TDes8 &, class TDes8 &, class TRequestStatus &)
	?GetConnectionState@RWLMServer@@QAE?AW4TWlanConnectionState@@XZ @ 34 NONAME ; enum TWlanConnectionState RWLMServer::GetConnectionState(void)
	?CancelDeleteTrafficStream@RWLMServer@@QAEXXZ @ 35 NONAME ; void RWLMServer::CancelDeleteTrafficStream(void)
	?DeleteTrafficStream@RWLMServer@@QAEXAAVTRequestStatus@@I@Z @ 36 NONAME ; void RWLMServer::DeleteTrafficStream(class TRequestStatus &, unsigned int)
	?SetPowerSaveSettings@RWLMServer@@QAEHABUTWlanPowerSaveSettings@@@Z @ 37 NONAME ; int RWLMServer::SetPowerSaveSettings(struct TWlanPowerSaveSettings const &)
	?NotifyChangedSettings@RWLMServer@@QAEXXZ @ 38 NONAME ; void RWLMServer::NotifyChangedSettings(void)
	?GetSystemMode@RWLMServer@@QAEHAAW4TWlanSystemMode@@@Z @ 39 NONAME ; int RWLMServer::GetSystemMode(enum TWlanSystemMode &)
	?Join@RWLMServer@@QAEXAAVTRequestStatus@@KPAUTWLMOverrideSettings@@@Z @ 40 NONAME ; void RWLMServer::Join(class TRequestStatus &, unsigned long, struct TWLMOverrideSettings *)
	?GetAvailableIaps@RWLMServer@@QAEHAAUTWlmAvailableIaps@@AAHAAI@Z @ 41 NONAME ; int RWLMServer::GetAvailableIaps(struct TWlmAvailableIaps &, int &, unsigned int &)
	?CancelNotifies@RWLMServer@@QAEXXZ @ 42 NONAME ; void RWLMServer::CancelNotifies(void)
	?UpdateRcpNotificationBoundary@RWLMServer@@QAEHJJ@Z @ 43 NONAME ; int RWLMServer::UpdateRcpNotificationBoundary(long, long)
	?CancelJoin@RWLMServer@@QAEXXZ @ 44 NONAME ; void RWLMServer::CancelJoin(void)
	?Connect@RWLMServer@@QAEHXZ @ 45 NONAME ; int RWLMServer::Connect(void)
	?SetPowerSaveMode@RWLMServer@@QAEHW4TWlanPowerSaveMode@@@Z @ 46 NONAME ; int RWLMServer::SetPowerSaveMode(enum TWlanPowerSaveMode)
	?GetPowerSaveSettings@RWLMServer@@QAEHAAUTWlanPowerSaveSettings@@@Z @ 47 NONAME ; int RWLMServer::GetPowerSaveSettings(struct TWlanPowerSaveSettings &)
	?StartAggressiveBgScan@RWLMServer@@QAEHI@Z @ 48 NONAME ; int RWLMServer::StartAggressiveBgScan(unsigned int)
